.. django-daraja documentation master file, created by
   sphinx-quickstart on Wed Oct 31 17:02:06 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to django-daraja's documentation!
=========================================

This is a django library that interacts with the MPESA Daraja API. Source code can be found https://github.com/martinmogusu/django-daraja.git MPESA Daraja documentattion can be found at https://developer.safaricom.co.ke

Installation
============
To install the library, run:

	..	code-block:: none

		pip install django_daraja

Documentation
=============

.. toctree::
   :maxdepth: 2
   
   pages/introduction
   pages/quick_start


.. toctree::
   :maxdepth: 2
   
   pages/apis/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
